ConnectQueryPayload class
Constructors
- ConnectQueryPayload({required String instance, required String collection, Filter? filter, int? offset, int? limit, int? sortProperty, bool sortAsc = true})
-
ConnectQueryPayload.fromJson(Map<
String, dynamic> json) -
factory
Properties
- collection → String
-
final
- filter → Filter?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance → String
-
final
- limit → int?
-
final
- offset → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortAsc → bool
-
final
- sortProperty → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toQuery(
Isar isar) → IsarQuery -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited